@@ -203,7 +203,7 @@ setMethod(
     nestedPath <- file.path(path, name) %>% checkPath(create = TRUE)
     filenameR <- file.path(nestedPath, paste0(name, ".R"))
 
-    children_char <- if (is.na(children) || length(children) == 0L) {
+    children_char <- if (any(is.na(children)) || length(children) == 0L) {
       "character(0)"
     } else {
       capture.output(dput(children))
@@ -254,7 +254,7 @@ defineModule(sim, list(
     if (type == "child") {
       cat("
 ## event types
-#   - type `init` is required for initialiazation
+#   - type `init` is required for initialization
 
 doEvent.", name, " = function(sim, eventTime, eventType) {
   switch(
@@ -331,8 +331,6 @@ doEvent.", name, " = function(sim, eventTime, eventType) {
 }
 
 ## event functions
-#   - follow the naming convention `modulenameEventtype()`;
-#   - `modulenameInit()` function is required for initiliazation;
 #   - keep event functions short and clean, modularize by calling subroutines from section below.
 
 ### template initialization
@@ -402,6 +400,11 @@ Event2 <- function(sim) {
   # if (!suppliedElsewhere('defaultColor', sim)) {
   #   sim$map <- Cache(prepInputs, extractURL('map')) # download, extract, load file from url in sourceURL
   # }
+
+  #cacheTags <- c(currentModule(sim), \"function:.inputObjects\") ## uncomment this if Cache is being used
+  dPath <- asPath(getOption(\"reproducible.destinationPath\", dataPath(sim)), 1)
+  message(currentModule(sim), \": using dataPath '\", dPath, \"'.\")
+
   # ! ----- EDIT BELOW ----- ! #
 
   # ! ----- STOP EDITING ----- ! #
