@@ -32,8 +32,8 @@ if (getRversion() >= "3.1.0") {
 #' @keywords internal
 #' @rdname doEvent
 #'
-doEvent <- function(sim, debug, notOlderThan) {
-  if (missing(debug)) debug <- FALSE
+doEvent <- function(sim, debug = FALSE, notOlderThan) {
+  #if (missing(debug)) debug <- FALSE
   #if (!inherits(sim, "simList")) stop("sim must be a simList")
   #if (!is(sim, "simList")) stop("sim must be a simList")
   if (class(sim) != "simList") { # faster than `is` and `inherits`
@@ -178,22 +178,27 @@ doEvent <- function(sim, debug, notOlderThan) {
             .modifySearchPath(sim@depends@dependencies[[cur[["moduleName"]]]]@reqdPkgs,
                               removeOthers = FALSE)
 
-          quotedFnCall <- if (cacheIt) { # means that a module or event is to be cached
-            quote(Cache(FUN = get(moduleCall, envir = fnEnv),
-                        sim = sim,
-                        eventTime = cur[["eventTime"]], eventType = cur[["eventType"]],
-                        objects = moduleSpecificObjects,
-                        notOlderThan = notOlderThan,
-                        outputObjects = moduleSpecificOutputObjects,
-                        classOptions = classOptions,
-                        cacheRepo = sim@paths[["cachePath"]]))
-          } else {
-            quote(get(moduleCall,
-                      envir = fnEnv)(sim, cur[["eventTime"]], cur[["eventType"]]))
-          }
           sim <- .runEvent(sim, cacheIt, debug,
-                           quotedFnCall = quotedFnCall,
                            moduleCall, fnEnv, cur, notOlderThan)
+
+          if (!exists(cur[["moduleName"]], envir = sim, inherits = FALSE))
+            stop("The module named ", cur[["moduleName"]], " just corrupted the object with that ",
+                 "name from from the simList. ",
+                 "Please remove the section of code that does this in the event named: ",
+                 cur[["eventType"]])
+
+          if (!is.environment(get(cur[["moduleName"]], envir = sim)))
+            stop("The module named ", cur[["moduleName"]], " just corrupted the object with that ",
+                 "name from from the simList. ",
+                 "Please remove the section of code that does this in the event named: ",
+                 cur[["eventType"]])
+
+          if (!exists("mod", envir = sim[[cur[["moduleName"]]]], inherits = FALSE))
+            stop("The module named ", cur[["moduleName"]], " just deleted the object named 'mod' from sim$",
+                 cur[["moduleName"]],". ",
+                 "Please remove the section of code that does this in the event named: ",
+                 cur[["eventType"]])
+
         }
       } else {
         stop(
@@ -258,6 +263,12 @@ doEvent <- function(sim, debug, notOlderThan) {
     }
 
   }
+
+  if (exists("objectSynonyms", envir = sim, inherits = FALSE)) {
+    sim <- .checkObjectSynonyms(sim)
+
+  }
+
   return(invisible(sim))
 }
 
@@ -275,7 +286,8 @@ doEvent <- function(sim, debug, notOlderThan) {
 #' @param eventTime      A numeric specifying the time of the next event.
 #'
 #' @param moduleName     A character string specifying the module from which to
-#'                       call the event.
+#'                       call the event. If missing, it will use
+#'                       \code{currentModule(sim)}
 #'
 #' @param eventType      A character string specifying the type of event from
 #'                       within the module.
@@ -283,6 +295,8 @@ doEvent <- function(sim, debug, notOlderThan) {
 #' @param eventPriority  A numeric specifying the priority of the event.
 #'                       Lower number means higher priority.
 #'                       See \code{\link{priority}}.
+#' @param .skipChecks Logical. If \code{TRUE}, then internal checks that arguments match
+#'                    expected types are skipped. Should only be used if speed is critical.
 #'
 #' @return Returns the modified \code{simList} object.
 #'
@@ -290,7 +304,7 @@ doEvent <- function(sim, debug, notOlderThan) {
 #' @include priority.R
 #' @export
 #' @rdname scheduleEvent
-#' @seealso \code{\link{priority}}
+#' @seealso \code{\link{priority}}, \code{\link{scheduleConditionalEvent}}
 #'
 #' @author Alex Chubaty
 #'
@@ -313,71 +327,36 @@ scheduleEvent <- function(sim,
                           eventTime,
                           moduleName,
                           eventType,
-                          eventPriority = .pkgEnv$.normalVal) {
+                          eventPriority = .pkgEnv$.normalVal,
+                          .skipChecks = FALSE) {
   #if (!inherits(sim, "simList")) stop("sim must be a simList")
   #if (!is(sim, "simList")) stop("sim must be a simList")
 
-  if (class(sim) != "simList") stop("sim must be a simList") # faster than `is` and `inherits`
+  if (missing(moduleName)) moduleName <- currentModule(sim)
 
-  if (!is.numeric(eventTime)) {
-    if (is.na(eventTime)) {
-      eventTime <- NA_real_
-    } else {
-      stop(paste(
-        "Invalid or missing eventTime. eventTime must be a numeric.",
-        "This is usually caused by an attempt to scheduleEvent at time NULL",
-        "or by using an undefined parameter."
-      ))
+  if (!.skipChecks) {
+    if (class(sim) != "simList") stop("sim must be a simList") # faster than `is` and `inherits`
+
+    if (!is.numeric(eventTime)) {
+      if (is.na(eventTime)) {
+        eventTime <- NA_real_
+      } else {
+        stop(paste(
+          "Invalid or missing eventTime. eventTime must be a numeric.",
+          "This is usually caused by an attempt to scheduleEvent at time NULL",
+          "or by using an undefined parameter."
+        ))
+      }
     }
-  }
-  if (!is.character(eventType)) stop("eventType must be a character")
-  if (!is.character(moduleName)) stop("moduleName must be a character")
-  #if (missing(eventPriority)) eventPriority <- .pkgEnv$.normalVal
-  if (!is.numeric(eventPriority)) stop("eventPriority must be a numeric")
+    if (!is.character(eventType)) stop("eventType must be a character")
+    if (!is.character(moduleName)) stop("moduleName must be a character")
+    #if (missing(eventPriority)) eventPriority <- .pkgEnv$.normalVal
+    if (!is.numeric(eventPriority)) stop("eventPriority must be a numeric")
 
+  }
   if (length(eventTime)) {
     if (!is.na(eventTime)) {
-      # if there is no metadata, meaning for the first
-      #  "default" modules...load, save, checkpoint, progress
-      if (!is.null(sim@depends@dependencies[[1]])) {
-        # first check if this moduleName matches the name of a module
-        #  with meta-data (i.e., depends(sim)@dependencies filled)
-        if (moduleName %in% unlist(lapply(sim@depends@dependencies, function(x) {
-          x@name
-        }))) {
-          # If the eventTime doesn't have units, it's a user generated
-          #  value, likely because of times in the simInit call.
-          #  This must be intercepted, and units added based on this
-          #  assumption, that the units are in \code{timeunit}
-          if (is.null(attr(eventTime, "unit"))) {
-            attributes(eventTime)$unit <- .callingFrameTimeunit(sim)
-            eventTimeInSeconds <- as.numeric(convertTimeunit((
-              eventTime -
-                convertTimeunit(sim@simtimes[["start"]],
-                                sim@simtimes[["timeunit"]], sim@.xData,
-                                skipChecks = TRUE)
-            ),
-            "seconds",
-            sim@.xData, skipChecks = TRUE) +
-              sim@simtimes[["current"]])
-          } else {
-            eventTimeInSeconds <- if (!startsWith(attr(eventTime, "unit"), "second")) {
-              as.numeric(convertTimeunit(eventTime, "seconds", sim@.xData,
-                                         skipChecks = TRUE))
-            } else eventTime
-          }
-        } else {
-          # for core modules because they have no metadata
-          eventTimeInSeconds <-
-            as.numeric(convertTimeunit(eventTime, "seconds", sim@.xData,
-                                       skipChecks = TRUE))
-        }
-      } else {
-        # when eventTime is NA... can't seem to get an example
-        eventTimeInSeconds <-
-          as.numeric(convertTimeunit(eventTime, "seconds", sim@.xData,
-                                     skipChecks = TRUE))
-      }
+      eventTimeInSeconds <- calculateEventTimeInSeconds(sim, eventTime, moduleName)
       attr(eventTimeInSeconds, "unit") <- "second"
 
       newEventList <- list(list(
@@ -390,13 +369,14 @@ scheduleEvent <- function(sim,
 
       # put new event into event queue
       if (numEvents == 0L) {
-        slot(sim, "events") <- newEventList
+        slot(sim, "events", check = FALSE) <- newEventList
       } else {
-        slot(sim, "events") <- append(sim@events, newEventList)
+        slot(sim, "events", check = FALSE) <- append(sim@events, newEventList)
         needSort <- TRUE
-        if (eventTimeInSeconds>sim@events[[numEvents]][[1]]) {
+        if (eventTimeInSeconds > sim@events[[numEvents]][[1]]) {
           needSort <- FALSE
-        } else if (eventTimeInSeconds==sim@events[[numEvents]][[1]] & eventPriority>=sim@events[[numEvents]][[4]]){
+        } else if (eventTimeInSeconds == sim@events[[numEvents]][[1]] &&
+                   eventPriority >= sim@events[[numEvents]][[4]]){
           needSort <- FALSE
         }
         if (needSort) {
@@ -419,6 +399,162 @@ scheduleEvent <- function(sim,
   return(invisible(sim))
 }
 
+################################################################################
+#' Schedule a conditional simulation event
+#'
+#' Adds a new event to the simulation's conditional event queue,
+#' updating the simulation object by creating or appending to
+#' \code{sim$._conditionalEvents}. This is very experimental. Use with caution.
+#'
+#' @inheritParams scheduleEvent
+#'
+#' @param minEventTime   A numeric specifying the time before which the event should not occur,
+#'         even if the condition is met. Defaults to \code{start(sim)}
+#'
+#' @param maxEventTime   A numeric specifying the time after which the event should not occur,
+#'         even if the condition is met. Defaults to \code{end(sim)}
+#'
+#' @param condition A string, call or expression that will be assessed for \code{TRUE}
+#'      after each event in the regular event queue.
+#'      It can access objects in the \code{simList} by using functions of \code{sim},
+#'      e.g., \code{"sim$age > 1"}
+#'
+#' @return Returns the modified \code{simList} object, i.e., \code{sim$._conditionalEvents}
+#'
+#' This conditional event queue will be assessed at every single event in the normal event
+#' queue. If there are no conditional events, then \code{spades} will proceed as normal. As
+#' conditional event conditions are found to be true, then it will trigger a call to
+#' \code{scheduleEvent(...)} with the current time passed to \code{eventTime} \emph{and} it will
+#' remove the conditional event from the conditional queue. If the user
+#' would like the triggered conditional event to occur as the very next event, then
+#' a possible strategy would be to set \code{eventPriority} of the conditional event to
+#' very low or even negative to ensure it gets inserted at the top of the event queue.
+#'
+#' @importFrom data.table setkey
+#' @include priority.R
+#' @export
+#' @rdname scheduleConditionalEvent
+#' @seealso \code{\link{scheduleEvent}}, \code{\link{conditionalEvents}}
+#'
+#' @author Eliot McIntire
+#'
+#' @references Matloff, N. (2011). The Art of R Programming (ch. 7.8.3).
+#'             San Francisco, CA: No Starch Press, Inc..
+#'             Retrieved from \url{https://www.nostarch.com/artofr.htm}
+#'
+#' @examples
+#'   sim <- simInit(times = list(start = 0, end = 2))
+#'   condition <- "sim$age > 1" # provide as string
+#'   condition <- quote(sim$age > 1) # provide as a call
+#'   condition <- expression(sim$age > 1) # provide as an expression
+#'   sim <- scheduleConditionalEvent(sim, condition, "firemodule", "burn")
+#'   conditionalEvents(sim)
+#'   sim <- spades(sim) # no changes to sim$age, i.e., it is absent
+#'   events(sim) # nothing scheduled
+#'   sim$age <- 2 # change the value
+#'   sim <- spades(sim) # Run spades, the condition is now true, so event is
+#'                      #  scheduled at current time
+#'   events(sim)        # now scheduled in the normal event queue
+scheduleConditionalEvent <- function(sim,
+                                     condition,
+                                     moduleName,
+                                     eventType,
+                                     eventPriority = .pkgEnv$.normalVal,
+                                     minEventTime = start(sim),
+                                     maxEventTime = end(sim)) {
+  if (class(sim) != "simList") stop("sim must be a simList") # faster than `is` and `inherits`
+
+  if (!is.numeric(minEventTime)) {
+    if (is.na(minEventTime)) {
+      eventTime <- NA_real_
+    } else {
+      stop(paste(
+        "Invalid or missing minEventTime. minEventTime must be a numeric.",
+        "This is usually caused by an attempt to scheduleEvent at time NULL",
+        "or by using an undefined parameter."
+      ))
+    }
+  }
+  if (!is.numeric(maxEventTime)) {
+    if (is.na(maxEventTime)) {
+      eventTime <- NA_real_
+    } else {
+      stop(paste(
+        "Invalid or missing maxEventTime. maxEventTime must be a numeric.",
+        "This is usually caused by an attempt to scheduleEvent at time NULL",
+        "or by using an undefined parameter."
+      ))
+    }
+  }
+
+  if (!is.character(eventType)) stop("eventType must be a character")
+  if (!is.character(moduleName)) stop("moduleName must be a character")
+  #if (missing(eventPriority)) eventPriority <- .pkgEnv$.normalVal
+  if (!is.numeric(eventPriority)) stop("eventPriority must be a numeric")
+
+  if (length(condition)) {
+    #if (!is.na(condition)) {
+
+    # Convert quote or "" to expression
+    if (is.call(condition)) {
+      cond <- as.expression(condition)
+    } else if (is.character(condition)) {
+      cond <- parse(text = condition)
+    } else if (is.expression(condition)) {
+      cond <- condition
+    } else {
+      stop("condition must be a character string or call or expression")
+    }
+
+    # minEventTime
+    minEventTimeInSeconds <- calculateEventTimeInSeconds(sim, minEventTime, moduleName)
+    attr(minEventTimeInSeconds, "unit") <- "second"
+
+    # maxEventTime
+    maxEventTimeInSeconds <- calculateEventTimeInSeconds(sim, maxEventTime, moduleName)
+    attr(maxEventTimeInSeconds, "unit") <- "second"
+
+    newEventList <- list(list(
+      condition = cond,
+      minEventTime = minEventTimeInSeconds,
+      maxEventTime = maxEventTimeInSeconds,
+      moduleName = moduleName,
+      eventType = eventType,
+      eventPriority = eventPriority
+    ))
+    numEvents <- length(sim$._conditionalEvents)
+
+    # put new event into event queue
+    if (numEvents == 0L) {
+      sim$._conditionalEvents <- newEventList
+    } else {
+      sim$._conditionalEvents <- append(sim$._conditionalEvents, newEventList)
+      needSort <- TRUE
+      if (minEventTimeInSeconds > sim$._conditionalEvents[[numEvents]]$minEventTime) {
+        needSort <- FALSE
+      } else if (minEventTimeInSeconds == sim$._conditionalEvents[[numEvents]]$minEventTime &
+                 eventPriority >= sim$._conditionalEvents[[numEvents]]$eventPriority){
+        needSort <- FALSE
+      }
+      if (needSort) {
+        ord <- order(unlist(lapply(sim$._conditionalEvents, function(x) x$eventTime)),
+                     unlist(lapply(sim$._conditionalEvents, function(x) x$eventPriority)))
+        sim$._conditionalEvents <- sim$._conditionalEvents[ord]
+      }
+      #      }
+    }
+  } else {
+    warning(
+      paste(
+        "Invalid or missing condition ",
+        "This is usually caused by an attempt to scheduleEvent at an empty condition ",
+        "or by using an undefined parameter."
+      )
+    )
+  }
+
+  return(invisible(sim))
+}
 
 ################################################################################
 #' Run a spatial discrete event simulation
@@ -593,7 +729,7 @@ setGeneric(
   function(sim, debug = getOption("spades.debug"), progress = NA, cache,
            .plotInitialTime = NULL, .saveInitialTime = NULL, notOlderThan = NULL, ...) {
     standardGeneric("spades")
-  })
+})
 
 #' @rdname spades
 setMethod(
@@ -607,6 +743,13 @@ setMethod(
                         .saveInitialTime,
                         notOlderThan,
                         ...) {
+
+    .pkgEnv$.sim <- NULL # Clear anything that was here.
+    # set the options("spades.xxxPath") to the values in the sim@paths
+    oldGetPaths <- getPaths()
+    do.call(setPaths, append(sim@paths, list(silent = TRUE)))
+    on.exit({do.call(setPaths, append(list(silent = TRUE), oldGetPaths))}, add = TRUE)
+
     sim@.xData[["._startClockTime"]] <- Sys.time()
     .pkgEnv$searchPath <- search()
     .pkgEnv[["spades.browserOnError"]] <-
@@ -621,7 +764,16 @@ setMethod(
       if (!.pkgEnv[["skipNamespacing"]])
         .modifySearchPath(.pkgEnv$searchPath, removeOthers = TRUE)
       rm(".timeunits", envir = sim@.xData)
-    })
+      if (isTRUE(getOption("spades.saveSimOnExit", FALSE))) {
+        if (!isTRUE(.pkgEnv$.cleanEnd)) {
+          .pkgEnv$.sim <- sim
+          message(
+            crayon::magenta("Because of an interrupted spades call, the sim object at the time of interruption ",
+                            "was saved in \nSpaDES.core:::.pkgEnv$.sim . It will be deleted on next call to spades"))
+        }
+        .pkgEnv$.cleanEnd <- NULL
+      }
+    }, add = TRUE)
 
     if (!is.null(.plotInitialTime)) {
       if (!is.numeric(.plotInitialTime))
@@ -682,10 +834,36 @@ setMethod(
     while (sim@simtimes[["current"]] <= sim@simtimes[["end"]]) {
       sim <- doEvent(sim, debug = debug, notOlderThan = notOlderThan)  # process the next event
 
+      # Conditional Scheduling -- adds only 900 nanoseconds per event, if none exist
+      if (exists("._conditionalEvents", envir = sim, inherits = FALSE)) {
+        condEventsToOmit <- integer()
+        for(condNum in seq(sim$._conditionalEvents)) {
+          cond <- sim$._conditionalEvents[[condNum]]
+          if (isTRUE(eval(cond$condition))) {
+            curTime <- time(sim)
+            if (curTime >= cond$minEventTime && curTime <= cond$maxEventTime) {
+              message("  Conditional Event -- ", cond$condition, " is true. Scheduling for now")
+              sim <- scheduleEvent(sim, eventTime = curTime, moduleName = cond$moduleName,
+                                   eventType = cond$eventType, eventPriority = cond$eventPriority)
+              condEventsToOmit <- c(condEventsToOmit, condNum)
+            }
+          }
+
+        }
+        if (length(condEventsToOmit)) {
+          sim$._conditionalEvents <- sim$._conditionalEvents[-condEventsToOmit]
+          if (length(sim$._conditionalEvents) == 0) {
+            rm("._conditionalEvents", envir = sim)
+          }
+        }
+      }
     }
     sim@simtimes[["current"]] <- sim@simtimes[["end"]]
+
+    # For determining if clean ending to spades call
+    .pkgEnv$.cleanEnd <- TRUE
     return(invisible(sim))
-  })
+})
 
 #' @rdname spades
 #' @importFrom reproducible Cache
@@ -700,7 +878,13 @@ setMethod(
                         .saveInitialTime,
                         notOlderThan = NULL,
                         ...) {
+
     stopifnot(class(sim) == "simList")
+
+    oldGetPaths <- getPaths()
+    do.call(setPaths, append(list(silent = TRUE), sim@paths))
+    on.exit({do.call(setPaths, append(list(silent = TRUE), oldGetPaths))}, add = TRUE)
+
     dots <- list(...)
     omitArgs <- "notOlderThan"
     if (isTRUE("omitArgs" %in% names(dots))) {
@@ -710,7 +894,7 @@ setMethod(
 
     if (cache) {
       return(
-        do.call(Cache,
+        do.call(quote = TRUE, Cache,
                 args = append(list(
                   spades,
                   sim = sim,
@@ -719,6 +903,7 @@ setMethod(
                   .plotInitialTime = .plotInitialTime,
                   .saveInitialTime = .saveInitialTime,
                   omitArgs = omitArgs, notOlderThan = notOlderThan),
+                  #cacheRepo = sim@paths$cachePath),
                   dots))
       )
     } else {
@@ -735,30 +920,50 @@ setMethod(
   })
 
 
-.runEvent <- function(sim, cacheIt, debug, quotedFnCall, moduleCall, fnEnv, cur, notOlderThan) {
+.runEvent <- function(sim, cacheIt, debug,
+                      moduleCall, fnEnv, cur, notOlderThan) {
   if (cacheIt) { # means that a module or event is to be cached
     createsOutputs <- sim@depends@dependencies[[cur[["moduleName"]]]]@outputObjects$objectName
+    fns <- ls(fnEnv, all.names = TRUE)
     moduleSpecificObjects <-
       c(ls(sim@.xData, all.names = TRUE, pattern = cur[["moduleName"]]), # functions in the main .xData that are prefixed with moduleName
-        ls(fnEnv, all.names = TRUE), # functions in the namespaced location
+        fns, # functions in the namespaced location
         na.omit(createsOutputs)) # objects outputted by module
-    moduleSpecificOutputObjects <- createsOutputs
+    #fnsWOhidden <- paste0(cur[["moduleName"]], ":",
+    #                      grep("^\\._", fns, value = TRUE, invert = TRUE))
+    moduleSpecificOutputObjects <- c(createsOutputs, cur[["moduleName"]])
     classOptions <- list(events = FALSE, current=FALSE, completed=FALSE, simtimes=FALSE,
                          params = sim@params[[cur[["moduleName"]]]],
                          modules = cur[["moduleName"]])
   }
-  if (.pkgEnv[["spades.browserOnError"]]) {
-    .runEventWithBrowser(sim, quotedFnCall, moduleCall, fnEnv, cur)
+  fnCallAsExpr <- if (cacheIt) { # means that a module or event is to be cached
+    expression(Cache(FUN = get(moduleCall, envir = fnEnv),
+                sim = sim,
+                     eventTime = cur[["eventTime"]], eventType = cur[["eventType"]],
+                     .objects = moduleSpecificObjects,
+                     notOlderThan = notOlderThan,
+                     outputObjects = moduleSpecificOutputObjects,
+                     classOptions = classOptions,
+                     cacheRepo = sim@paths[["cachePath"]]))
   } else {
-    eval(quotedFnCall)
+    # Faster just to pass the NULL and just call it directly inside .runEvent
+    expression(get(moduleCall,
+                   envir = fnEnv)(sim, cur[["eventTime"]], cur[["eventType"]]))
+  }
+
+  if (.pkgEnv[["spades.browserOnError"]]) {
+    .runEventWithBrowser(sim, fnCallAsExpr, moduleCall, fnEnv, cur)
+  } else {
+    #fnEnv[[moduleCall]](sim, cur[["eventTime"]], cur[["eventType"]])
+    eval(fnCallAsExpr) # slower than more direct version just above
   }
 }
 
-.runEventWithBrowser <- function(sim, quotedFnCall, moduleCall, fnEnv, cur) {
+.runEventWithBrowser <- function(sim, fnCallAsExpr, moduleCall, fnEnv, cur) {
   canContinue <- TRUE
   numTries <- 0
   while(canContinue) {
-    out <- try(eval(quotedFnCall))
+    out <- try(eval(fnCallAsExpr))
     if (isTRUE(is(out, "try-error"))) {
       numTries <- numTries + 1
       if (numTries > 1) {
@@ -778,3 +983,36 @@ setMethod(
   }
   sim <- out
 }
+
+calculateEventTimeInSeconds <- function(sim, eventTime, moduleName) {
+  #if (!is.null(sim@depends@dependencies[[1]])) {
+  unitAttr <- attr(eventTime, "unit")
+  if (is.null(unitAttr)) {
+    attributes(eventTime)$unit <- .callingFrameTimeunit(sim)
+    eventTime <- as.numeric(convertTimeunit((
+      eventTime -
+        convertTimeunit(sim@simtimes[["start"]],
+                        sim@simtimes[["timeunit"]], sim@.xData,
+                        skipChecks = TRUE)
+    ),
+    "seconds",
+    sim@.xData, skipChecks = TRUE) +
+      sim@simtimes[["current"]])
+  } else {
+    #if (!startsWith(unitAttr, "second")) {
+    if (unitAttr != "second") { # faster to do 2 sequential tests like this than !startsWith
+      if (unitAttr != "seconds") {
+        eventTime <- as.numeric(convertTimeunit(eventTime, "seconds", sim@.xData,
+                                                skipChecks = TRUE))
+      }
+    }
+  } #else eventTime
+
+  #} else {
+  # when eventTime is NA... can't seem to get an example
+  #eventTimeInSeconds <-
+  #  as.numeric(convertTimeunit(eventTime, "seconds", sim@.xData,
+  #                             skipChecks = TRUE))
+  #}
+  eventTime
+}
